@@ -413,7 +413,7 @@ class Button(sprite):
     def set_text(self, text, color="white", padding=0.05):
         _text = textZone(
             name=f"textZone_{self.name}",
-            size=Vector2(self.rect.size),
+            size=Vector2(*self.rect.size),
             text_color=color
         )
 
